MethodChannelZebraHandheldScanner class

An implementation of ZebraHandheldScannerPlatform that uses method channels.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

autoConnectBle() Future<String>
override
disconnect() Future<void>
override
getBatteryLevel() Future<int?>
override
getDeviceName() Future<String?>
override
getPlatformVersion() Future<String?>
override
getVersion() Future<String?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestPermissions() Future<bool>
override
sendCommand(String command) Future<void>
override
setDeviceName(String name) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited