ZebraHandheldScannerPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- ZebraHandheldScannerPlatform
- Implementers
Constructors
- ZebraHandheldScannerPlatform()
- Constructs a ZebraHandheldScannerPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
autoConnectBle(
) → Future< String> -
disconnect(
) → Future< void> -
getBatteryLevel(
) → Future< int?> -
getDeviceName(
) → Future< String?> -
getPlatformVersion(
) → Future< String?> -
getVersion(
) → Future< String?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
requestPermissions(
) → Future< bool> -
sendCommand(
String command) → Future< void> -
setDeviceName(
String name) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ ZebraHandheldScannerPlatform
-
The default instance of ZebraHandheldScannerPlatform to use.
getter/setter pair